@@ -3,6 +3,12 @@ Exceptions raised by OS base classes
 """
 
 
+class ClipboardError(Exception):
+    """
+    Errors raised by clipbaord access
+    """
+
+
 class CommandError(Exception):
     """
     Exceptions raised by shell commands
@@ -25,3 +31,9 @@ class FileParserError(Exception):
     """
     Exceptions raised while parsing text files
     """
+
+
+class SecureTemporaryDirectoryError(Exception):
+    """
+    Exceptions raised while processing secure temporary directories
+    """
